@@ -1,3 +1,4 @@
+# pylint: disable=no-value-for-parameter
 from dagster_shell import create_shell_command_solid
 
 from dagster import pipeline
@@ -5,5 +6,5 @@ from dagster import pipeline
 
 @pipeline
 def pipe():
-    a = create_shell_command_solid('echo "hello, world!"', name='a')
+    a = create_shell_command_solid('echo "hello, world!"', name="a")
     a()
